# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Contracts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contract_address': 'str',
        'creator_address': 'str',
        'deployment_time': 'int',
        'is_open_source': 'int',
        'malicious_behavior': 'list[object]',
        'malicious_contract': 'int',
        'malicious_creator': 'int',
        'malicious_creator_behavior': 'list[object]'
    }

    attribute_map = {
        'contract_address': 'contract_address',
        'creator_address': 'creator_address',
        'deployment_time': 'deployment_time',
        'is_open_source': 'is_open_source',
        'malicious_behavior': 'malicious_behavior',
        'malicious_contract': 'malicious_contract',
        'malicious_creator': 'malicious_creator',
        'malicious_creator_behavior': 'malicious_creator_behavior'
    }

    def __init__(self, contract_address=None, creator_address=None, deployment_time=None, is_open_source=None, malicious_behavior=None, malicious_contract=None, malicious_creator=None, malicious_creator_behavior=None):  # noqa: E501
        """Contracts - a model defined in Swagger"""  # noqa: E501
        self._contract_address = None
        self._creator_address = None
        self._deployment_time = None
        self._is_open_source = None
        self._malicious_behavior = None
        self._malicious_contract = None
        self._malicious_creator = None
        self._malicious_creator_behavior = None
        self.discriminator = None
        if contract_address is not None:
            self.contract_address = contract_address
        if creator_address is not None:
            self.creator_address = creator_address
        if deployment_time is not None:
            self.deployment_time = deployment_time
        if is_open_source is not None:
            self.is_open_source = is_open_source
        if malicious_behavior is not None:
            self.malicious_behavior = malicious_behavior
        if malicious_contract is not None:
            self.malicious_contract = malicious_contract
        if malicious_creator is not None:
            self.malicious_creator = malicious_creator
        if malicious_creator_behavior is not None:
            self.malicious_creator_behavior = malicious_creator_behavior

    @property
    def contract_address(self):
        """Gets the contract_address of this Contracts.  # noqa: E501

        It describes the dAap's contract address.  # noqa: E501

        :return: The contract_address of this Contracts.  # noqa: E501
        :rtype: str
        """
        return self._contract_address

    @contract_address.setter
    def contract_address(self, contract_address):
        """Sets the contract_address of this Contracts.

        It describes the dAap's contract address.  # noqa: E501

        :param contract_address: The contract_address of this Contracts.  # noqa: E501
        :type: str
        """

        self._contract_address = contract_address

    @property
    def creator_address(self):
        """Gets the creator_address of this Contracts.  # noqa: E501

        It describes the creator address of the contract.  # noqa: E501

        :return: The creator_address of this Contracts.  # noqa: E501
        :rtype: str
        """
        return self._creator_address

    @creator_address.setter
    def creator_address(self, creator_address):
        """Sets the creator_address of this Contracts.

        It describes the creator address of the contract.  # noqa: E501

        :param creator_address: The creator_address of this Contracts.  # noqa: E501
        :type: str
        """

        self._creator_address = creator_address

    @property
    def deployment_time(self):
        """Gets the deployment_time of this Contracts.  # noqa: E501

        It describes the deployed time of the contract.The value is presented as a timestamp. Example: \"deployed_time\": 1626578345  # noqa: E501

        :return: The deployment_time of this Contracts.  # noqa: E501
        :rtype: int
        """
        return self._deployment_time

    @deployment_time.setter
    def deployment_time(self, deployment_time):
        """Sets the deployment_time of this Contracts.

        It describes the deployed time of the contract.The value is presented as a timestamp. Example: \"deployed_time\": 1626578345  # noqa: E501

        :param deployment_time: The deployment_time of this Contracts.  # noqa: E501
        :type: int
        """

        self._deployment_time = deployment_time

    @property
    def is_open_source(self):
        """Gets the is_open_source of this Contracts.  # noqa: E501

        It describes whether this contract is open source. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The is_open_source of this Contracts.  # noqa: E501
        :rtype: int
        """
        return self._is_open_source

    @is_open_source.setter
    def is_open_source(self, is_open_source):
        """Sets the is_open_source of this Contracts.

        It describes whether this contract is open source. \"1\" means true; \"0\" means false.  # noqa: E501

        :param is_open_source: The is_open_source of this Contracts.  # noqa: E501
        :type: int
        """

        self._is_open_source = is_open_source

    @property
    def malicious_behavior(self):
        """Gets the malicious_behavior of this Contracts.  # noqa: E501

        It describes specific malicious behaviors of the contract.  # noqa: E501

        :return: The malicious_behavior of this Contracts.  # noqa: E501
        :rtype: list[object]
        """
        return self._malicious_behavior

    @malicious_behavior.setter
    def malicious_behavior(self, malicious_behavior):
        """Sets the malicious_behavior of this Contracts.

        It describes specific malicious behaviors of the contract.  # noqa: E501

        :param malicious_behavior: The malicious_behavior of this Contracts.  # noqa: E501
        :type: list[object]
        """

        self._malicious_behavior = malicious_behavior

    @property
    def malicious_contract(self):
        """Gets the malicious_contract of this Contracts.  # noqa: E501

        It describes whether the address is a suspected malicious contract. \"1\" means true; \"0\" means that we have not found malicious behavior of this contract.(Notice:\"malicious_contract\" return \"0\" does not mean the address is completely safe. Maybe we just haven't found its malicious behavior.)  # noqa: E501

        :return: The malicious_contract of this Contracts.  # noqa: E501
        :rtype: int
        """
        return self._malicious_contract

    @malicious_contract.setter
    def malicious_contract(self, malicious_contract):
        """Sets the malicious_contract of this Contracts.

        It describes whether the address is a suspected malicious contract. \"1\" means true; \"0\" means that we have not found malicious behavior of this contract.(Notice:\"malicious_contract\" return \"0\" does not mean the address is completely safe. Maybe we just haven't found its malicious behavior.)  # noqa: E501

        :param malicious_contract: The malicious_contract of this Contracts.  # noqa: E501
        :type: int
        """

        self._malicious_contract = malicious_contract

    @property
    def malicious_creator(self):
        """Gets the malicious_creator of this Contracts.  # noqa: E501

        It describes whether the creator is a suspected malicious address. \"1\" means true; \"0\" means that we have not found malicious behavior of this address.(Notice:\"malicious_creator\" return \"0\" does not mean the address is completely safe. Maybe we just haven't found its malicious behavior.)  # noqa: E501

        :return: The malicious_creator of this Contracts.  # noqa: E501
        :rtype: int
        """
        return self._malicious_creator

    @malicious_creator.setter
    def malicious_creator(self, malicious_creator):
        """Sets the malicious_creator of this Contracts.

        It describes whether the creator is a suspected malicious address. \"1\" means true; \"0\" means that we have not found malicious behavior of this address.(Notice:\"malicious_creator\" return \"0\" does not mean the address is completely safe. Maybe we just haven't found its malicious behavior.)  # noqa: E501

        :param malicious_creator: The malicious_creator of this Contracts.  # noqa: E501
        :type: int
        """

        self._malicious_creator = malicious_creator

    @property
    def malicious_creator_behavior(self):
        """Gets the malicious_creator_behavior of this Contracts.  # noqa: E501

        It describes specific malicious behaviors of the contract creator.  # noqa: E501

        :return: The malicious_creator_behavior of this Contracts.  # noqa: E501
        :rtype: list[object]
        """
        return self._malicious_creator_behavior

    @malicious_creator_behavior.setter
    def malicious_creator_behavior(self, malicious_creator_behavior):
        """Sets the malicious_creator_behavior of this Contracts.

        It describes specific malicious behaviors of the contract creator.  # noqa: E501

        :param malicious_creator_behavior: The malicious_creator_behavior of this Contracts.  # noqa: E501
        :type: list[object]
        """

        self._malicious_creator_behavior = malicious_creator_behavior

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Contracts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Contracts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperTokenSecurityResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'note': 'str',
        'lp_total_supply': 'str',
        'lp_holders': 'list[ResponseWrapperTokenSecurityLpHolders]',
        'is_airdrop_scam': 'str',
        'other_potential_risks': 'str',
        'transfer_pausable': 'str',
        'trading_cooldown': 'str',
        'hidden_owner': 'str',
        'selfdestruct': 'str',
        'owner_percent': 'str',
        'is_whitelisted': 'str',
        'holder_count': 'str',
        'trust_list': 'str',
        'is_honeypot': 'str',
        'honeypot_with_same_creator': 'str',
        'holders': 'list[ResponseWrapperTokenSecurityLpHolders]',
        'dex': 'list[ResponseWrapperTokenSecurityDex]',
        'is_open_source': 'str',
        'sell_tax': 'str',
        'token_name': 'str',
        'creator_address': 'str',
        'creator_percent': 'str',
        'is_proxy': 'str',
        'creator_balance': 'str',
        'is_in_dex': 'str',
        'owner_balance': 'str',
        'total_supply': 'str',
        'is_true_token': 'str',
        'can_take_back_ownership': 'str',
        'is_blacklisted': 'str',
        'owner_address': 'str',
        'slippage_modifiable': 'str',
        'buy_tax': 'str',
        'external_call': 'str',
        'cannot_sell_all': 'str',
        'lp_holder_count': 'str',
        'personal_slippage_modifiable': 'str',
        'is_anti_whale': 'str',
        'is_mintable': 'str',
        'owner_change_balance': 'str',
        'cannot_buy': 'str',
        'anti_whale_modifiable': 'str',
        'token_symbol': 'str'
    }

    attribute_map = {
        'note': 'note',
        'lp_total_supply': 'lp_total_supply',
        'lp_holders': 'lp_holders',
        'is_airdrop_scam': 'is_airdrop_scam',
        'other_potential_risks': 'other_potential_risks',
        'transfer_pausable': 'transfer_pausable',
        'trading_cooldown': 'trading_cooldown',
        'hidden_owner': 'hidden_owner',
        'selfdestruct': 'selfdestruct',
        'owner_percent': 'owner_percent',
        'is_whitelisted': 'is_whitelisted',
        'holder_count': 'holder_count',
        'trust_list': 'trust_list',
        'is_honeypot': 'is_honeypot',
        'honeypot_with_same_creator': 'honeypot_with_same_creator',
        'holders': 'holders',
        'dex': 'dex',
        'is_open_source': 'is_open_source',
        'sell_tax': 'sell_tax',
        'token_name': 'token_name',
        'creator_address': 'creator_address',
        'creator_percent': 'creator_percent',
        'is_proxy': 'is_proxy',
        'creator_balance': 'creator_balance',
        'is_in_dex': 'is_in_dex',
        'owner_balance': 'owner_balance',
        'total_supply': 'total_supply',
        'is_true_token': 'is_true_token',
        'can_take_back_ownership': 'can_take_back_ownership',
        'is_blacklisted': 'is_blacklisted',
        'owner_address': 'owner_address',
        'slippage_modifiable': 'slippage_modifiable',
        'buy_tax': 'buy_tax',
        'external_call': 'external_call',
        'cannot_sell_all': 'cannot_sell_all',
        'lp_holder_count': 'lp_holder_count',
        'personal_slippage_modifiable': 'personal_slippage_modifiable',
        'is_anti_whale': 'is_anti_whale',
        'is_mintable': 'is_mintable',
        'owner_change_balance': 'owner_change_balance',
        'cannot_buy': 'cannot_buy',
        'anti_whale_modifiable': 'anti_whale_modifiable',
        'token_symbol': 'token_symbol'
    }

    def __init__(self, note=None, lp_total_supply=None, lp_holders=None, is_airdrop_scam=None, other_potential_risks=None, transfer_pausable=None, trading_cooldown=None, hidden_owner=None, selfdestruct=None, owner_percent=None, is_whitelisted=None, holder_count=None, trust_list=None, is_honeypot=None, honeypot_with_same_creator=None, holders=None, dex=None, is_open_source=None, sell_tax=None, token_name=None, creator_address=None, creator_percent=None, is_proxy=None, creator_balance=None, is_in_dex=None, owner_balance=None, total_supply=None, is_true_token=None, can_take_back_ownership=None, is_blacklisted=None, owner_address=None, slippage_modifiable=None, buy_tax=None, external_call=None, cannot_sell_all=None, lp_holder_count=None, personal_slippage_modifiable=None, is_anti_whale=None, is_mintable=None, owner_change_balance=None, cannot_buy=None, anti_whale_modifiable=None, token_symbol=None):  # noqa: E501
        """ResponseWrapperTokenSecurityResult - a model defined in Swagger"""  # noqa: E501
        self._note = None
        self._lp_total_supply = None
        self._lp_holders = None
        self._is_airdrop_scam = None
        self._other_potential_risks = None
        self._transfer_pausable = None
        self._trading_cooldown = None
        self._hidden_owner = None
        self._selfdestruct = None
        self._owner_percent = None
        self._is_whitelisted = None
        self._holder_count = None
        self._trust_list = None
        self._is_honeypot = None
        self._honeypot_with_same_creator = None
        self._holders = None
        self._dex = None
        self._is_open_source = None
        self._sell_tax = None
        self._token_name = None
        self._creator_address = None
        self._creator_percent = None
        self._is_proxy = None
        self._creator_balance = None
        self._is_in_dex = None
        self._owner_balance = None
        self._total_supply = None
        self._is_true_token = None
        self._can_take_back_ownership = None
        self._is_blacklisted = None
        self._owner_address = None
        self._slippage_modifiable = None
        self._buy_tax = None
        self._external_call = None
        self._cannot_sell_all = None
        self._lp_holder_count = None
        self._personal_slippage_modifiable = None
        self._is_anti_whale = None
        self._is_mintable = None
        self._owner_change_balance = None
        self._cannot_buy = None
        self._anti_whale_modifiable = None
        self._token_symbol = None
        self.discriminator = None
        if note is not None:
            self.note = note
        if lp_total_supply is not None:
            self.lp_total_supply = lp_total_supply
        if lp_holders is not None:
            self.lp_holders = lp_holders
        if is_airdrop_scam is not None:
            self.is_airdrop_scam = is_airdrop_scam
        if other_potential_risks is not None:
            self.other_potential_risks = other_potential_risks
        if transfer_pausable is not None:
            self.transfer_pausable = transfer_pausable
        if trading_cooldown is not None:
            self.trading_cooldown = trading_cooldown
        if hidden_owner is not None:
            self.hidden_owner = hidden_owner
        if selfdestruct is not None:
            self.selfdestruct = selfdestruct
        if owner_percent is not None:
            self.owner_percent = owner_percent
        if is_whitelisted is not None:
            self.is_whitelisted = is_whitelisted
        if holder_count is not None:
            self.holder_count = holder_count
        if trust_list is not None:
            self.trust_list = trust_list
        if is_honeypot is not None:
            self.is_honeypot = is_honeypot
        if honeypot_with_same_creator is not None:
            self.honeypot_with_same_creator = honeypot_with_same_creator
        if holders is not None:
            self.holders = holders
        if dex is not None:
            self.dex = dex
        if is_open_source is not None:
            self.is_open_source = is_open_source
        if sell_tax is not None:
            self.sell_tax = sell_tax
        if token_name is not None:
            self.token_name = token_name
        if creator_address is not None:
            self.creator_address = creator_address
        if creator_percent is not None:
            self.creator_percent = creator_percent
        if is_proxy is not None:
            self.is_proxy = is_proxy
        if creator_balance is not None:
            self.creator_balance = creator_balance
        if is_in_dex is not None:
            self.is_in_dex = is_in_dex
        if owner_balance is not None:
            self.owner_balance = owner_balance
        if total_supply is not None:
            self.total_supply = total_supply
        if is_true_token is not None:
            self.is_true_token = is_true_token
        if can_take_back_ownership is not None:
            self.can_take_back_ownership = can_take_back_ownership
        if is_blacklisted is not None:
            self.is_blacklisted = is_blacklisted
        if owner_address is not None:
            self.owner_address = owner_address
        if slippage_modifiable is not None:
            self.slippage_modifiable = slippage_modifiable
        if buy_tax is not None:
            self.buy_tax = buy_tax
        if external_call is not None:
            self.external_call = external_call
        if cannot_sell_all is not None:
            self.cannot_sell_all = cannot_sell_all
        if lp_holder_count is not None:
            self.lp_holder_count = lp_holder_count
        if personal_slippage_modifiable is not None:
            self.personal_slippage_modifiable = personal_slippage_modifiable
        if is_anti_whale is not None:
            self.is_anti_whale = is_anti_whale
        if is_mintable is not None:
            self.is_mintable = is_mintable
        if owner_change_balance is not None:
            self.owner_change_balance = owner_change_balance
        if cannot_buy is not None:
            self.cannot_buy = cannot_buy
        if anti_whale_modifiable is not None:
            self.anti_whale_modifiable = anti_whale_modifiable
        if token_symbol is not None:
            self.token_symbol = token_symbol

    @property
    def note(self):
        """Gets the note of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract has other things investors need to know.  Example:  \"note\": \"Contract owner is a multisign contract.\"(Notice:(1) If we haven't found any other thing which is valuable yet, there will be no return.  (2) Type: string.)  # noqa: E501

        :return: The note of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract has other things investors need to know.  Example:  \"note\": \"Contract owner is a multisign contract.\"(Notice:(1) If we haven't found any other thing which is valuable yet, there will be no return.  (2) Type: string.)  # noqa: E501

        :param note: The note of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def lp_total_supply(self):
        """Gets the lp_total_supply of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the supply number of the LP token. Example:\"lp_total_supply\": \"100000000\". No return means no LP.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) It is LP token number, NOT token number)  # noqa: E501

        :return: The lp_total_supply of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._lp_total_supply

    @lp_total_supply.setter
    def lp_total_supply(self, lp_total_supply):
        """Sets the lp_total_supply of this ResponseWrapperTokenSecurityResult.

        It describes the supply number of the LP token. Example:\"lp_total_supply\": \"100000000\". No return means no LP.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) It is LP token number, NOT token number)  # noqa: E501

        :param lp_total_supply: The lp_total_supply of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._lp_total_supply = lp_total_supply

    @property
    def lp_holders(self):
        """Gets the lp_holders of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        Top10 LP token holders info(Notice:When \"is_in_dex\": \"0\", there will be no return. )  # noqa: E501

        :return: The lp_holders of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: list[ResponseWrapperTokenSecurityLpHolders]
        """
        return self._lp_holders

    @lp_holders.setter
    def lp_holders(self, lp_holders):
        """Sets the lp_holders of this ResponseWrapperTokenSecurityResult.

        Top10 LP token holders info(Notice:When \"is_in_dex\": \"0\", there will be no return. )  # noqa: E501

        :param lp_holders: The lp_holders of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: list[ResponseWrapperTokenSecurityLpHolders]
        """

        self._lp_holders = lp_holders

    @property
    def is_airdrop_scam(self):
        """Gets the is_airdrop_scam of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the token is an airdrop scam. \"1\" means true; \"0\" means false; None means no result (Because We did not find conclusive information on whether token is an airdrop scam).(Notice:Only \"is_airdrop_scam\": \"1\" means it is an airdrop scam.)  # noqa: E501

        :return: The is_airdrop_scam of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_airdrop_scam

    @is_airdrop_scam.setter
    def is_airdrop_scam(self, is_airdrop_scam):
        """Sets the is_airdrop_scam of this ResponseWrapperTokenSecurityResult.

        It describes whether the token is an airdrop scam. \"1\" means true; \"0\" means false; None means no result (Because We did not find conclusive information on whether token is an airdrop scam).(Notice:Only \"is_airdrop_scam\": \"1\" means it is an airdrop scam.)  # noqa: E501

        :param is_airdrop_scam: The is_airdrop_scam of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_airdrop_scam = is_airdrop_scam

    @property
    def other_potential_risks(self):
        """Gets the other_potential_risks of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract has other potential risks. Example: \"other_potential_risks\": \"Owner can set different transaction taxes for each user, which can trigger serious losses.\"(Notice:(1) If we haven't found any other potential risk yet, there will be no return.  (2) Type: string.)  # noqa: E501

        :return: The other_potential_risks of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._other_potential_risks

    @other_potential_risks.setter
    def other_potential_risks(self, other_potential_risks):
        """Sets the other_potential_risks of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract has other potential risks. Example: \"other_potential_risks\": \"Owner can set different transaction taxes for each user, which can trigger serious losses.\"(Notice:(1) If we haven't found any other potential risk yet, there will be no return.  (2) Type: string.)  # noqa: E501

        :param other_potential_risks: The other_potential_risks of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._other_potential_risks = other_potential_risks

    @property
    def transfer_pausable(self):
        """Gets the transfer_pausable of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether trading can be pausable by token contract. \"1\" means true; \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) This feature means that the contract owner will be able to suspend trading at any time, after that anyone will not be able to sell, except those who have special authority.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :return: The transfer_pausable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._transfer_pausable

    @transfer_pausable.setter
    def transfer_pausable(self, transfer_pausable):
        """Sets the transfer_pausable of this ResponseWrapperTokenSecurityResult.

        It describes whether trading can be pausable by token contract. \"1\" means true; \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) This feature means that the contract owner will be able to suspend trading at any time, after that anyone will not be able to sell, except those who have special authority.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :param transfer_pausable: The transfer_pausable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._transfer_pausable = transfer_pausable

    @property
    def trading_cooldown(self):
        """Gets the trading_cooldown of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract has trading-cool-down mechanism which can limits the minimum time between two transactions. \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return. (2) Sometimes, when \"is_proxy\": \"1\", there will be no return. )  # noqa: E501

        :return: The trading_cooldown of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._trading_cooldown

    @trading_cooldown.setter
    def trading_cooldown(self, trading_cooldown):
        """Sets the trading_cooldown of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract has trading-cool-down mechanism which can limits the minimum time between two transactions. \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return. (2) Sometimes, when \"is_proxy\": \"1\", there will be no return. )  # noqa: E501

        :param trading_cooldown: The trading_cooldown of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._trading_cooldown = trading_cooldown

    @property
    def hidden_owner(self):
        """Gets the hidden_owner of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract has hidden owners. For contract with a hidden owner, developer can still manipulate the contract even if the ownership has been abandoned. \"1\" means true; \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Hidden owner is often used by developers to hide ownership and is often accompanied by malicious functionality. When the hidden owner exists, it is assumed that ownership has not been abandoned.)  # noqa: E501

        :return: The hidden_owner of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._hidden_owner

    @hidden_owner.setter
    def hidden_owner(self, hidden_owner):
        """Sets the hidden_owner of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract has hidden owners. For contract with a hidden owner, developer can still manipulate the contract even if the ownership has been abandoned. \"1\" means true; \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Hidden owner is often used by developers to hide ownership and is often accompanied by malicious functionality. When the hidden owner exists, it is assumed that ownership has not been abandoned.)  # noqa: E501

        :param hidden_owner: The hidden_owner of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._hidden_owner = hidden_owner

    @property
    def selfdestruct(self):
        """Gets the selfdestruct of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether this contract can self destruct. \"1\" means true;  \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) When the self-destruct function is triggered, this contract will be destroyed, all functions will be unavailable, and all related assets will be erased.)  # noqa: E501

        :return: The selfdestruct of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._selfdestruct

    @selfdestruct.setter
    def selfdestruct(self, selfdestruct):
        """Sets the selfdestruct of this ResponseWrapperTokenSecurityResult.

        It describes whether this contract can self destruct. \"1\" means true;  \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) When the self-destruct function is triggered, this contract will be destroyed, all functions will be unavailable, and all related assets will be erased.)  # noqa: E501

        :param selfdestruct: The selfdestruct of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._selfdestruct = selfdestruct

    @property
    def owner_percent(self):
        """Gets the owner_percent of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the percentage of tokens held by the contract owner.  Example:\"owner_balance\": \"0.1\".  No return or return empty means there is no ownership or can't find ownership.(Notice:(1) 1 means 100% here. (2) When \"owner_address\" returns empty, or no return, there will be no return.)  # noqa: E501

        :return: The owner_percent of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._owner_percent

    @owner_percent.setter
    def owner_percent(self, owner_percent):
        """Sets the owner_percent of this ResponseWrapperTokenSecurityResult.

        It describes the percentage of tokens held by the contract owner.  Example:\"owner_balance\": \"0.1\".  No return or return empty means there is no ownership or can't find ownership.(Notice:(1) 1 means 100% here. (2) When \"owner_address\" returns empty, or no return, there will be no return.)  # noqa: E501

        :param owner_percent: The owner_percent of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._owner_percent = owner_percent

    @property
    def is_whitelisted(self):
        """Gets the is_whitelisted of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the whitelist function is not included in the contract. If there is a whitelist, some addresses may not be able to trade normally. \"1\" means true; \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Whitelisting is mostly used to allow specific addresses to make early transactions, tax-free, and not affected by transaction suspension. (4) For contracts without an owner (or the owner is a black hole address), the whitelist will not be able to get updated. However, the existing whitelist is still in effect.)  # noqa: E501

        :return: The is_whitelisted of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_whitelisted

    @is_whitelisted.setter
    def is_whitelisted(self, is_whitelisted):
        """Sets the is_whitelisted of this ResponseWrapperTokenSecurityResult.

        It describes whether the whitelist function is not included in the contract. If there is a whitelist, some addresses may not be able to trade normally. \"1\" means true; \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Whitelisting is mostly used to allow specific addresses to make early transactions, tax-free, and not affected by transaction suspension. (4) For contracts without an owner (or the owner is a black hole address), the whitelist will not be able to get updated. However, the existing whitelist is still in effect.)  # noqa: E501

        :param is_whitelisted: The is_whitelisted of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_whitelisted = is_whitelisted

    @property
    def holder_count(self):
        """Gets the holder_count of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the number of token holders. Example:\"holder_count\": \"4342\"  # noqa: E501

        :return: The holder_count of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._holder_count

    @holder_count.setter
    def holder_count(self, holder_count):
        """Sets the holder_count of this ResponseWrapperTokenSecurityResult.

        It describes the number of token holders. Example:\"holder_count\": \"4342\"  # noqa: E501

        :param holder_count: The holder_count of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._holder_count = holder_count

    @property
    def trust_list(self):
        """Gets the trust_list of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the token is a famous and trustworthy one. \"1\" means true; No return no result (Because We did not find conclusive information on whether token is a airdrop scam).(Notice:(1) Only \"trust_list\": \"1\" means it is a famous and trustworthy token.  (2) No return doesn't mean it is risky.)  # noqa: E501

        :return: The trust_list of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._trust_list

    @trust_list.setter
    def trust_list(self, trust_list):
        """Sets the trust_list of this ResponseWrapperTokenSecurityResult.

        It describes whether the token is a famous and trustworthy one. \"1\" means true; No return no result (Because We did not find conclusive information on whether token is a airdrop scam).(Notice:(1) Only \"trust_list\": \"1\" means it is a famous and trustworthy token.  (2) No return doesn't mean it is risky.)  # noqa: E501

        :param trust_list: The trust_list of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._trust_list = trust_list

    @property
    def is_honeypot(self):
        """Gets the is_honeypot of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the token is a honeypot. \"HoneyPot\" means that the token maybe cannot be sold because of the token contract's function, Or the token contains malicious code.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Hight risk, definitely scam.)  # noqa: E501

        :return: The is_honeypot of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_honeypot

    @is_honeypot.setter
    def is_honeypot(self, is_honeypot):
        """Sets the is_honeypot of this ResponseWrapperTokenSecurityResult.

        It describes whether the token is a honeypot. \"HoneyPot\" means that the token maybe cannot be sold because of the token contract's function, Or the token contains malicious code.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Hight risk, definitely scam.)  # noqa: E501

        :param is_honeypot: The is_honeypot of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_honeypot = is_honeypot

    @property
    def honeypot_with_same_creator(self):
        """Gets the honeypot_with_same_creator of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the number of honeypot tokens created by this creator.  # noqa: E501

        :return: The honeypot_with_same_creator of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._honeypot_with_same_creator

    @honeypot_with_same_creator.setter
    def honeypot_with_same_creator(self, honeypot_with_same_creator):
        """Sets the honeypot_with_same_creator of this ResponseWrapperTokenSecurityResult.

        It describes the number of honeypot tokens created by this creator.  # noqa: E501

        :param honeypot_with_same_creator: The honeypot_with_same_creator of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._honeypot_with_same_creator = honeypot_with_same_creator

    @property
    def holders(self):
        """Gets the holders of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        Top10 holders info  # noqa: E501

        :return: The holders of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: list[ResponseWrapperTokenSecurityLpHolders]
        """
        return self._holders

    @holders.setter
    def holders(self, holders):
        """Sets the holders of this ResponseWrapperTokenSecurityResult.

        Top10 holders info  # noqa: E501

        :param holders: The holders of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: list[ResponseWrapperTokenSecurityLpHolders]
        """

        self._holders = holders

    @property
    def dex(self):
        """Gets the dex of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes Dex information of where the token that can be traded.(Notice:When \"is_in_dex\": \"0\", there will be empty array. )  # noqa: E501

        :return: The dex of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: list[ResponseWrapperTokenSecurityDex]
        """
        return self._dex

    @dex.setter
    def dex(self, dex):
        """Sets the dex of this ResponseWrapperTokenSecurityResult.

        It describes Dex information of where the token that can be traded.(Notice:When \"is_in_dex\": \"0\", there will be empty array. )  # noqa: E501

        :param dex: The dex of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: list[ResponseWrapperTokenSecurityDex]
        """

        self._dex = dex

    @property
    def is_open_source(self):
        """Gets the is_open_source of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :return: The is_open_source of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_open_source

    @is_open_source.setter
    def is_open_source(self, is_open_source):
        """Sets the is_open_source of this ResponseWrapperTokenSecurityResult.

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :param is_open_source: The is_open_source of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_open_source = is_open_source

    @property
    def sell_tax(self):
        """Gets the sell_tax of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the tax when selling the token.  Example: \"sell_tax\": 0.1%.  No return means unknown.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) Sell tax will cause the actual value received when selling a token to be less than expected, and too much buy tax may lead to large losses. (3) When \"sell_tax\": \"1\", it means sell-tax is 100% or this token cannot be sold. (4) Sometimes token's  trading-cool-down mechanism would affect our sandbox system. When \"trading_cooldown\": \"1\", \"sell_tax\" may return \"1\".)  # noqa: E501

        :return: The sell_tax of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._sell_tax

    @sell_tax.setter
    def sell_tax(self, sell_tax):
        """Sets the sell_tax of this ResponseWrapperTokenSecurityResult.

        It describes the tax when selling the token.  Example: \"sell_tax\": 0.1%.  No return means unknown.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) Sell tax will cause the actual value received when selling a token to be less than expected, and too much buy tax may lead to large losses. (3) When \"sell_tax\": \"1\", it means sell-tax is 100% or this token cannot be sold. (4) Sometimes token's  trading-cool-down mechanism would affect our sandbox system. When \"trading_cooldown\": \"1\", \"sell_tax\" may return \"1\".)  # noqa: E501

        :param sell_tax: The sell_tax of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._sell_tax = sell_tax

    @property
    def token_name(self):
        """Gets the token_name of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        Token Name  # noqa: E501

        :return: The token_name of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._token_name

    @token_name.setter
    def token_name(self, token_name):
        """Sets the token_name of this ResponseWrapperTokenSecurityResult.

        Token Name  # noqa: E501

        :param token_name: The token_name of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._token_name = token_name

    @property
    def creator_address(self):
        """Gets the creator_address of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes this contract's owner address.  Example: \"creator_address\": \"0x744aF9cBb7606BB040f6FBf1c0a0B0dcBA6385E5\";  # noqa: E501

        :return: The creator_address of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._creator_address

    @creator_address.setter
    def creator_address(self, creator_address):
        """Sets the creator_address of this ResponseWrapperTokenSecurityResult.

        It describes this contract's owner address.  Example: \"creator_address\": \"0x744aF9cBb7606BB040f6FBf1c0a0B0dcBA6385E5\";  # noqa: E501

        :param creator_address: The creator_address of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._creator_address = creator_address

    @property
    def creator_percent(self):
        """Gets the creator_percent of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the percentage of tokens held by the contract owner. Example:\"owner_balance\": 0.1.(Notice:1 means 100% here.)  # noqa: E501

        :return: The creator_percent of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._creator_percent

    @creator_percent.setter
    def creator_percent(self, creator_percent):
        """Sets the creator_percent of this ResponseWrapperTokenSecurityResult.

        It describes the percentage of tokens held by the contract owner. Example:\"owner_balance\": 0.1.(Notice:1 means 100% here.)  # noqa: E501

        :param creator_percent: The creator_percent of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._creator_percent = creator_percent

    @property
    def is_proxy(self):
        """Gets the is_proxy of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether this contract has a proxy contract.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Most Proxy contracts are accompanied by modifiable implementation contracts, and implementation contracts may contain significant potential risk. When the contract is a Proxy, we will stop detecting other risk items.)  # noqa: E501

        :return: The is_proxy of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_proxy

    @is_proxy.setter
    def is_proxy(self, is_proxy):
        """Sets the is_proxy of this ResponseWrapperTokenSecurityResult.

        It describes whether this contract has a proxy contract.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Most Proxy contracts are accompanied by modifiable implementation contracts, and implementation contracts may contain significant potential risk. When the contract is a Proxy, we will stop detecting other risk items.)  # noqa: E501

        :param is_proxy: The is_proxy of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_proxy = is_proxy

    @property
    def creator_balance(self):
        """Gets the creator_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the balance of the contract owner.  Example:\"owner_balance\": 100000000.  # noqa: E501

        :return: The creator_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._creator_balance

    @creator_balance.setter
    def creator_balance(self, creator_balance):
        """Sets the creator_balance of this ResponseWrapperTokenSecurityResult.

        It describes the balance of the contract owner.  Example:\"owner_balance\": 100000000.  # noqa: E501

        :param creator_balance: The creator_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._creator_balance = creator_balance

    @property
    def is_in_dex(self):
        """Gets the is_in_dex of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the token can be traded on the main Dex. \"1\" means true; \"0\" means false(Notice:It only counts when the token has a marketing pair with mainstream coins/tokens.)  # noqa: E501

        :return: The is_in_dex of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_in_dex

    @is_in_dex.setter
    def is_in_dex(self, is_in_dex):
        """Sets the is_in_dex of this ResponseWrapperTokenSecurityResult.

        It describes whether the token can be traded on the main Dex. \"1\" means true; \"0\" means false(Notice:It only counts when the token has a marketing pair with mainstream coins/tokens.)  # noqa: E501

        :param is_in_dex: The is_in_dex of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_in_dex = is_in_dex

    @property
    def owner_balance(self):
        """Gets the owner_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the balance of the contract owner.  Example: \"owner_balance\": \"100000000\".  No return or return empty means there is no ownership or can't find ownership.(Notice:When \"owner_address\" returns empty, or no return, there will be no return.)  # noqa: E501

        :return: The owner_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._owner_balance

    @owner_balance.setter
    def owner_balance(self, owner_balance):
        """Sets the owner_balance of this ResponseWrapperTokenSecurityResult.

        It describes the balance of the contract owner.  Example: \"owner_balance\": \"100000000\".  No return or return empty means there is no ownership or can't find ownership.(Notice:When \"owner_address\" returns empty, or no return, there will be no return.)  # noqa: E501

        :param owner_balance: The owner_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._owner_balance = owner_balance

    @property
    def total_supply(self):
        """Gets the total_supply of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the supply number of the token. Example:\"total_supply\": 100000000  # noqa: E501

        :return: The total_supply of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._total_supply

    @total_supply.setter
    def total_supply(self, total_supply):
        """Sets the total_supply of this ResponseWrapperTokenSecurityResult.

        It describes the supply number of the token. Example:\"total_supply\": 100000000  # noqa: E501

        :param total_supply: The total_supply of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._total_supply = total_supply

    @property
    def is_true_token(self):
        """Gets the is_true_token of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the token is true or fake. \"1\" means true token; \"0\" means fake token; None means no result (Because we did not find decisive information about the truth or falsity)(Notice:Only \"is_true_token\": \"0\" means it is a fake token.)  # noqa: E501

        :return: The is_true_token of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_true_token

    @is_true_token.setter
    def is_true_token(self, is_true_token):
        """Sets the is_true_token of this ResponseWrapperTokenSecurityResult.

        It describes whether the token is true or fake. \"1\" means true token; \"0\" means fake token; None means no result (Because we did not find decisive information about the truth or falsity)(Notice:Only \"is_true_token\": \"0\" means it is a fake token.)  # noqa: E501

        :param is_true_token: The is_true_token of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_true_token = is_true_token

    @property
    def can_take_back_ownership(self):
        """Gets the can_take_back_ownership of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether this contract has the function to take back ownership.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Ownership is mostly used to adjust the parameters and status of the contract, such as minting, modification of slippage, suspension of trading, setting blacklsit, etc.  When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, these functions will most likely be disabled.)  # noqa: E501

        :return: The can_take_back_ownership of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._can_take_back_ownership

    @can_take_back_ownership.setter
    def can_take_back_ownership(self, can_take_back_ownership):
        """Sets the can_take_back_ownership of this ResponseWrapperTokenSecurityResult.

        It describes whether this contract has the function to take back ownership.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Ownership is mostly used to adjust the parameters and status of the contract, such as minting, modification of slippage, suspension of trading, setting blacklsit, etc.  When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, these functions will most likely be disabled.)  # noqa: E501

        :param can_take_back_ownership: The can_take_back_ownership of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._can_take_back_ownership = can_take_back_ownership

    @property
    def is_blacklisted(self):
        """Gets the is_blacklisted of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the blacklist function is not included in the contract. If there is a blacklist, some addresses may not be able to trade normally. \"1\" means true; \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\",  there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) The contract owner may add any address into the blacklist, and the token holder in blacklist will not be able to trade. Abuse of the blacklist function will lead to great risks.  (4) For contracts without an owner (or the owner is a black hole address), the blacklist will not be able to get updated. However, the existing blacklist is still in effect.)  # noqa: E501

        :return: The is_blacklisted of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_blacklisted

    @is_blacklisted.setter
    def is_blacklisted(self, is_blacklisted):
        """Sets the is_blacklisted of this ResponseWrapperTokenSecurityResult.

        It describes whether the blacklist function is not included in the contract. If there is a blacklist, some addresses may not be able to trade normally. \"1\" means true; \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\",  there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) The contract owner may add any address into the blacklist, and the token holder in blacklist will not be able to trade. Abuse of the blacklist function will lead to great risks.  (4) For contracts without an owner (or the owner is a black hole address), the blacklist will not be able to get updated. However, the existing blacklist is still in effect.)  # noqa: E501

        :param is_blacklisted: The is_blacklisted of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_blacklisted = is_blacklisted

    @property
    def owner_address(self):
        """Gets the owner_address of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes this contract's owner address.  Example: \"owner_address\": \"0x744aF9cBb7606BB040f6FBf1c0a0B0dcBA6385E5\";  No return means unknown; Return empty means there is no ownership or can't find ownership.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Ownership is mostly used to adjust the parameters and status of the contract, such as minting, modification of slippage, suspension of trading, setting blacklist, etc.  When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, these functions will most likely be disabled.)  # noqa: E501

        :return: The owner_address of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._owner_address

    @owner_address.setter
    def owner_address(self, owner_address):
        """Sets the owner_address of this ResponseWrapperTokenSecurityResult.

        It describes this contract's owner address.  Example: \"owner_address\": \"0x744aF9cBb7606BB040f6FBf1c0a0B0dcBA6385E5\";  No return means unknown; Return empty means there is no ownership or can't find ownership.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Ownership is mostly used to adjust the parameters and status of the contract, such as minting, modification of slippage, suspension of trading, setting blacklist, etc.  When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, these functions will most likely be disabled.)  # noqa: E501

        :param owner_address: The owner_address of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._owner_address = owner_address

    @property
    def slippage_modifiable(self):
        """Gets the slippage_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the trading tax can be modifiable by token contract. \"1\" means true; \"0\" means false; No return means unknown.(Notice:(1) When When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Token with modifiable tax means that the contract owner can modify the buy tax or sell tax of the token. This may cause some losses, especially since some contracts have unlimited modifiable tax rates, which would make the token untradeable.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :return: The slippage_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._slippage_modifiable

    @slippage_modifiable.setter
    def slippage_modifiable(self, slippage_modifiable):
        """Sets the slippage_modifiable of this ResponseWrapperTokenSecurityResult.

        It describes whether the trading tax can be modifiable by token contract. \"1\" means true; \"0\" means false; No return means unknown.(Notice:(1) When When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Token with modifiable tax means that the contract owner can modify the buy tax or sell tax of the token. This may cause some losses, especially since some contracts have unlimited modifiable tax rates, which would make the token untradeable.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :param slippage_modifiable: The slippage_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._slippage_modifiable = slippage_modifiable

    @property
    def buy_tax(self):
        """Gets the buy_tax of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the tax when buying the token.  Example: \"buy_tax\": 0.1%.  No return means unknown.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) Buy tax will cause the actual value received when buying a token to be less than expected, and too much buy tax may lead to heavy losses. (3) When \"buy_tax\": \"1\", it means buy tax is 100% or cannot buy. (4) Sometimes token's anti-bot mechanism would affect our sandbox system, leading to \"cannoy_buy\": \"1\",  causing the display of \"buy_tax\": \"1\". (5)Some of the token is deisgned not for sale, leading to \"cannot_buy\":1, causing the display of \"buy_tax\": \"1\".)  # noqa: E501

        :return: The buy_tax of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._buy_tax

    @buy_tax.setter
    def buy_tax(self, buy_tax):
        """Sets the buy_tax of this ResponseWrapperTokenSecurityResult.

        It describes the tax when buying the token.  Example: \"buy_tax\": 0.1%.  No return means unknown.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) Buy tax will cause the actual value received when buying a token to be less than expected, and too much buy tax may lead to heavy losses. (3) When \"buy_tax\": \"1\", it means buy tax is 100% or cannot buy. (4) Sometimes token's anti-bot mechanism would affect our sandbox system, leading to \"cannoy_buy\": \"1\",  causing the display of \"buy_tax\": \"1\". (5)Some of the token is deisgned not for sale, leading to \"cannot_buy\":1, causing the display of \"buy_tax\": \"1\".)  # noqa: E501

        :param buy_tax: The buy_tax of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._buy_tax = buy_tax

    @property
    def external_call(self):
        """Gets the external_call of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract would call functions of other contracts when primary methods are executed. \"1\" means true;  \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) External call would cause the implementation of this contract to be highly dependent on other external contracts, which may be a potential risk.)  # noqa: E501

        :return: The external_call of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._external_call

    @external_call.setter
    def external_call(self, external_call):
        """Sets the external_call of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract would call functions of other contracts when primary methods are executed. \"1\" means true;  \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) External call would cause the implementation of this contract to be highly dependent on other external contracts, which may be a potential risk.)  # noqa: E501

        :param external_call: The external_call of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._external_call = external_call

    @property
    def cannot_sell_all(self):
        """Gets the cannot_sell_all of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract has the function restricting token holder selling all the token.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) This feature means that you will not be able to sell all your tokens in a single sale. Sometimes you need to leave a certain percentage of the token, e.g. 10%, sometimes you need to leave a fixed number of token, such as 10 token. (3) When \"buy_tax\": \"1\", there will be no return.)  # noqa: E501

        :return: The cannot_sell_all of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._cannot_sell_all

    @cannot_sell_all.setter
    def cannot_sell_all(self, cannot_sell_all):
        """Sets the cannot_sell_all of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract has the function restricting token holder selling all the token.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_in_dex\": \"0\", there will be no return.  (2) This feature means that you will not be able to sell all your tokens in a single sale. Sometimes you need to leave a certain percentage of the token, e.g. 10%, sometimes you need to leave a fixed number of token, such as 10 token. (3) When \"buy_tax\": \"1\", there will be no return.)  # noqa: E501

        :param cannot_sell_all: The cannot_sell_all of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._cannot_sell_all = cannot_sell_all

    @property
    def lp_holder_count(self):
        """Gets the lp_holder_count of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes the number of LP token holders. Example:\"lp_holder_count\": \"4342\". No return means no LP.(Notice:When \"is_in_dex\": \"0\", there will be no return.)  # noqa: E501

        :return: The lp_holder_count of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._lp_holder_count

    @lp_holder_count.setter
    def lp_holder_count(self, lp_holder_count):
        """Sets the lp_holder_count of this ResponseWrapperTokenSecurityResult.

        It describes the number of LP token holders. Example:\"lp_holder_count\": \"4342\". No return means no LP.(Notice:When \"is_in_dex\": \"0\", there will be no return.)  # noqa: E501

        :param lp_holder_count: The lp_holder_count of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._lp_holder_count = lp_holder_count

    @property
    def personal_slippage_modifiable(self):
        """Gets the personal_slippage_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the owner can set a different tax rate for every assigned address. \"1\" means ture; \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\",  there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) The contract owner may set a very outrageous tax rate for assigned address to block it from trading. Abuse of this funtcion will lead to great risks.  (4) For contracts without an owner (or the owner is a black hole address), this function would not able to be used. However, the existing tax rate would be still in effect.)  # noqa: E501

        :return: The personal_slippage_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._personal_slippage_modifiable

    @personal_slippage_modifiable.setter
    def personal_slippage_modifiable(self, personal_slippage_modifiable):
        """Sets the personal_slippage_modifiable of this ResponseWrapperTokenSecurityResult.

        It describes whether the owner can set a different tax rate for every assigned address. \"1\" means ture; \"0\" means false; No return means unknown.(Notice:(1) When \"is_open_source\": \"0\",  there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) The contract owner may set a very outrageous tax rate for assigned address to block it from trading. Abuse of this funtcion will lead to great risks.  (4) For contracts without an owner (or the owner is a black hole address), this function would not able to be used. However, the existing tax rate would be still in effect.)  # noqa: E501

        :param personal_slippage_modifiable: The personal_slippage_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._personal_slippage_modifiable = personal_slippage_modifiable

    @property
    def is_anti_whale(self):
        """Gets the is_anti_whale of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract has the function to limit the maximum amount of transactions or the maximum token position that for single address.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return. (2) Sometimes, when \"is_proxy\": \"1\", there will be no return. )  # noqa: E501

        :return: The is_anti_whale of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_anti_whale

    @is_anti_whale.setter
    def is_anti_whale(self, is_anti_whale):
        """Sets the is_anti_whale of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract has the function to limit the maximum amount of transactions or the maximum token position that for single address.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return. (2) Sometimes, when \"is_proxy\": \"1\", there will be no return. )  # noqa: E501

        :param is_anti_whale: The is_anti_whale of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_anti_whale = is_anti_whale

    @property
    def is_mintable(self):
        """Gets the is_mintable of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether this contract has the function to mint tokens.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Mint function will directly trigger a massive sell-off, causing the coin price to plummet. It is extremely risky.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :return: The is_mintable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._is_mintable

    @is_mintable.setter
    def is_mintable(self, is_mintable):
        """Sets the is_mintable of this ResponseWrapperTokenSecurityResult.

        It describes whether this contract has the function to mint tokens.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Mint function will directly trigger a massive sell-off, causing the coin price to plummet. It is extremely risky.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :param is_mintable: The is_mintable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._is_mintable = is_mintable

    @property
    def owner_change_balance(self):
        """Gets the owner_change_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract owner has the authority to change the balance of any token holder.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Token with this feature means that the owner can modify anyone's balance, resulting in an asset straight to zero or a massive minting and sell-off.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :return: The owner_change_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._owner_change_balance

    @owner_change_balance.setter
    def owner_change_balance(self, owner_change_balance):
        """Sets the owner_change_balance of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract owner has the authority to change the balance of any token holder.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return.  (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3) Token with this feature means that the owner can modify anyone's balance, resulting in an asset straight to zero or a massive minting and sell-off.  (4) This function generally relies on ownership. When the contract does not have an owner (or if the owner is a black hole address) and the owner cannot be retrieved, this function will most likely be disabled.)  # noqa: E501

        :param owner_change_balance: The owner_change_balance of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._owner_change_balance = owner_change_balance

    @property
    def cannot_buy(self):
        """Gets the cannot_buy of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It deiscribes whether the Token can be bought. \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) Generally, \"cannot_buy\": \"1\" would be found in Reward Tokens. Such Tokens are issued as rewards for some on-chain applications and cannot be bought directly by users. (2) Sometimes token's anti-bot mechanism would affect our sandbox system, causing the display of \"buy_tax\": \"1\". (3) When \"cannot_buy\": \"1\", our sandbox system might be bloked, causing the display of \"buy_tax\": \"1\" and \"sell_tax\": \"1\")  # noqa: E501

        :return: The cannot_buy of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._cannot_buy

    @cannot_buy.setter
    def cannot_buy(self, cannot_buy):
        """Sets the cannot_buy of this ResponseWrapperTokenSecurityResult.

        It deiscribes whether the Token can be bought. \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) Generally, \"cannot_buy\": \"1\" would be found in Reward Tokens. Such Tokens are issued as rewards for some on-chain applications and cannot be bought directly by users. (2) Sometimes token's anti-bot mechanism would affect our sandbox system, causing the display of \"buy_tax\": \"1\". (3) When \"cannot_buy\": \"1\", our sandbox system might be bloked, causing the display of \"buy_tax\": \"1\" and \"sell_tax\": \"1\")  # noqa: E501

        :param cannot_buy: The cannot_buy of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._cannot_buy = cannot_buy

    @property
    def anti_whale_modifiable(self):
        """Gets the anti_whale_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        It describes whether the contract has the function to modify the maximum amount of transactions or the maximum token position.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return. (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3)When the anti whale value is set to a very small value, all tradinge would fail.)  # noqa: E501

        :return: The anti_whale_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._anti_whale_modifiable

    @anti_whale_modifiable.setter
    def anti_whale_modifiable(self, anti_whale_modifiable):
        """Sets the anti_whale_modifiable of this ResponseWrapperTokenSecurityResult.

        It describes whether the contract has the function to modify the maximum amount of transactions or the maximum token position.  \"1\" means true;  \"0\" means false;  No return means unknown.(Notice:(1) When \"is_open_source\": \"0\", there will be no return. (2) Sometimes, when \"is_proxy\": \"1\", there will be no return.  (3)When the anti whale value is set to a very small value, all tradinge would fail.)  # noqa: E501

        :param anti_whale_modifiable: The anti_whale_modifiable of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._anti_whale_modifiable = anti_whale_modifiable

    @property
    def token_symbol(self):
        """Gets the token_symbol of this ResponseWrapperTokenSecurityResult.  # noqa: E501

        Token Symbol  # noqa: E501

        :return: The token_symbol of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :rtype: str
        """
        return self._token_symbol

    @token_symbol.setter
    def token_symbol(self, token_symbol):
        """Sets the token_symbol of this ResponseWrapperTokenSecurityResult.

        Token Symbol  # noqa: E501

        :param token_symbol: The token_symbol of this ResponseWrapperTokenSecurityResult.  # noqa: E501
        :type: str
        """

        self._token_symbol = token_symbol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperTokenSecurityResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperTokenSecurityResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApproveNFTListResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'approved_list': 'list[ApproveResult]',
        'chain_id': 'str',
        'is_open_source': 'int',
        'is_verified': 'int',
        'malicious_address': 'int',
        'malicious_behavior': 'list[str]',
        'nft_address': 'str',
        'nft_name': 'str',
        'nft_symbol': 'str'
    }

    attribute_map = {
        'approved_list': 'approved_list',
        'chain_id': 'chain_id',
        'is_open_source': 'is_open_source',
        'is_verified': 'is_verified',
        'malicious_address': 'malicious_address',
        'malicious_behavior': 'malicious_behavior',
        'nft_address': 'nft_address',
        'nft_name': 'nft_name',
        'nft_symbol': 'nft_symbol'
    }

    def __init__(self, approved_list=None, chain_id=None, is_open_source=None, is_verified=None, malicious_address=None, malicious_behavior=None, nft_address=None, nft_name=None, nft_symbol=None):  # noqa: E501
        """ApproveNFTListResponse - a model defined in Swagger"""  # noqa: E501
        self._approved_list = None
        self._chain_id = None
        self._is_open_source = None
        self._is_verified = None
        self._malicious_address = None
        self._malicious_behavior = None
        self._nft_address = None
        self._nft_name = None
        self._nft_symbol = None
        self.discriminator = None
        if approved_list is not None:
            self.approved_list = approved_list
        if chain_id is not None:
            self.chain_id = chain_id
        if is_open_source is not None:
            self.is_open_source = is_open_source
        if is_verified is not None:
            self.is_verified = is_verified
        if malicious_address is not None:
            self.malicious_address = malicious_address
        if malicious_behavior is not None:
            self.malicious_behavior = malicious_behavior
        if nft_address is not None:
            self.nft_address = nft_address
        if nft_name is not None:
            self.nft_name = nft_name
        if nft_symbol is not None:
            self.nft_symbol = nft_symbol

    @property
    def approved_list(self):
        """Gets the approved_list of this ApproveNFTListResponse.  # noqa: E501


        :return: The approved_list of this ApproveNFTListResponse.  # noqa: E501
        :rtype: list[ApproveResult]
        """
        return self._approved_list

    @approved_list.setter
    def approved_list(self, approved_list):
        """Sets the approved_list of this ApproveNFTListResponse.


        :param approved_list: The approved_list of this ApproveNFTListResponse.  # noqa: E501
        :type: list[ApproveResult]
        """

        self._approved_list = approved_list

    @property
    def chain_id(self):
        """Gets the chain_id of this ApproveNFTListResponse.  # noqa: E501

        ChainID  # noqa: E501

        :return: The chain_id of this ApproveNFTListResponse.  # noqa: E501
        :rtype: str
        """
        return self._chain_id

    @chain_id.setter
    def chain_id(self, chain_id):
        """Sets the chain_id of this ApproveNFTListResponse.

        ChainID  # noqa: E501

        :param chain_id: The chain_id of this ApproveNFTListResponse.  # noqa: E501
        :type: str
        """

        self._chain_id = chain_id

    @property
    def is_open_source(self):
        """Gets the is_open_source of this ApproveNFTListResponse.  # noqa: E501

        Whether the contract is verified on blockchain explorer.  # noqa: E501

        :return: The is_open_source of this ApproveNFTListResponse.  # noqa: E501
        :rtype: int
        """
        return self._is_open_source

    @is_open_source.setter
    def is_open_source(self, is_open_source):
        """Sets the is_open_source of this ApproveNFTListResponse.

        Whether the contract is verified on blockchain explorer.  # noqa: E501

        :param is_open_source: The is_open_source of this ApproveNFTListResponse.  # noqa: E501
        :type: int
        """

        self._is_open_source = is_open_source

    @property
    def is_verified(self):
        """Gets the is_verified of this ApproveNFTListResponse.  # noqa: E501

        Whether NFT is certified on a reputable trading platform.  # noqa: E501

        :return: The is_verified of this ApproveNFTListResponse.  # noqa: E501
        :rtype: int
        """
        return self._is_verified

    @is_verified.setter
    def is_verified(self, is_verified):
        """Sets the is_verified of this ApproveNFTListResponse.

        Whether NFT is certified on a reputable trading platform.  # noqa: E501

        :param is_verified: The is_verified of this ApproveNFTListResponse.  # noqa: E501
        :type: int
        """

        self._is_verified = is_verified

    @property
    def malicious_address(self):
        """Gets the malicious_address of this ApproveNFTListResponse.  # noqa: E501

        Whether the NFT is malicious or contains high risk.  # noqa: E501

        :return: The malicious_address of this ApproveNFTListResponse.  # noqa: E501
        :rtype: int
        """
        return self._malicious_address

    @malicious_address.setter
    def malicious_address(self, malicious_address):
        """Sets the malicious_address of this ApproveNFTListResponse.

        Whether the NFT is malicious or contains high risk.  # noqa: E501

        :param malicious_address: The malicious_address of this ApproveNFTListResponse.  # noqa: E501
        :type: int
        """

        self._malicious_address = malicious_address

    @property
    def malicious_behavior(self):
        """Gets the malicious_behavior of this ApproveNFTListResponse.  # noqa: E501

        Specific malicious behaviors or risks of this NFT.  # noqa: E501

        :return: The malicious_behavior of this ApproveNFTListResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._malicious_behavior

    @malicious_behavior.setter
    def malicious_behavior(self, malicious_behavior):
        """Sets the malicious_behavior of this ApproveNFTListResponse.

        Specific malicious behaviors or risks of this NFT.  # noqa: E501

        :param malicious_behavior: The malicious_behavior of this ApproveNFTListResponse.  # noqa: E501
        :type: list[str]
        """

        self._malicious_behavior = malicious_behavior

    @property
    def nft_address(self):
        """Gets the nft_address of this ApproveNFTListResponse.  # noqa: E501

        nft address  # noqa: E501

        :return: The nft_address of this ApproveNFTListResponse.  # noqa: E501
        :rtype: str
        """
        return self._nft_address

    @nft_address.setter
    def nft_address(self, nft_address):
        """Sets the nft_address of this ApproveNFTListResponse.

        nft address  # noqa: E501

        :param nft_address: The nft_address of this ApproveNFTListResponse.  # noqa: E501
        :type: str
        """

        self._nft_address = nft_address

    @property
    def nft_name(self):
        """Gets the nft_name of this ApproveNFTListResponse.  # noqa: E501

        NFT name  # noqa: E501

        :return: The nft_name of this ApproveNFTListResponse.  # noqa: E501
        :rtype: str
        """
        return self._nft_name

    @nft_name.setter
    def nft_name(self, nft_name):
        """Sets the nft_name of this ApproveNFTListResponse.

        NFT name  # noqa: E501

        :param nft_name: The nft_name of this ApproveNFTListResponse.  # noqa: E501
        :type: str
        """

        self._nft_name = nft_name

    @property
    def nft_symbol(self):
        """Gets the nft_symbol of this ApproveNFTListResponse.  # noqa: E501

        NFT symbol  # noqa: E501

        :return: The nft_symbol of this ApproveNFTListResponse.  # noqa: E501
        :rtype: str
        """
        return self._nft_symbol

    @nft_symbol.setter
    def nft_symbol(self, nft_symbol):
        """Sets the nft_symbol of this ApproveNFTListResponse.

        NFT symbol  # noqa: E501

        :param nft_symbol: The nft_symbol of this ApproveNFTListResponse.  # noqa: E501
        :type: str
        """

        self._nft_symbol = nft_symbol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApproveNFTListResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApproveNFTListResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperTokenSecurityLpHolders(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_locked': 'int',
        'is_contract': 'int',
        'address': 'str',
        'balance': 'str',
        'locked_detail': 'list[ResponseWrapperTokenSecurityLockedDetail]',
        'tag': 'str',
        'percent': 'str'
    }

    attribute_map = {
        'is_locked': 'is_locked',
        'is_contract': 'is_contract',
        'address': 'address',
        'balance': 'balance',
        'locked_detail': 'locked_detail',
        'tag': 'tag',
        'percent': 'percent'
    }

    def __init__(self, is_locked=None, is_contract=None, address=None, balance=None, locked_detail=None, tag=None, percent=None):  # noqa: E501
        """ResponseWrapperTokenSecurityLpHolders - a model defined in Swagger"""  # noqa: E501
        self._is_locked = None
        self._is_contract = None
        self._address = None
        self._balance = None
        self._locked_detail = None
        self._tag = None
        self._percent = None
        self.discriminator = None
        if is_locked is not None:
            self.is_locked = is_locked
        if is_contract is not None:
            self.is_contract = is_contract
        if address is not None:
            self.address = address
        if balance is not None:
            self.balance = balance
        if locked_detail is not None:
            self.locked_detail = locked_detail
        if tag is not None:
            self.tag = tag
        if percent is not None:
            self.percent = percent

    @property
    def is_locked(self):
        """Gets the is_locked of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501

        It describes whether the tokens owned by the holder are locked \"1\" means true; \"0\" means false;  (3) \"tag\" describes the address's public tag. Example:Burn (Notice:About \"locked\": We only support the token lock addresses or black hole addresses that we have included. )  # noqa: E501

        :return: The is_locked of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :rtype: int
        """
        return self._is_locked

    @is_locked.setter
    def is_locked(self, is_locked):
        """Sets the is_locked of this ResponseWrapperTokenSecurityLpHolders.

        It describes whether the tokens owned by the holder are locked \"1\" means true; \"0\" means false;  (3) \"tag\" describes the address's public tag. Example:Burn (Notice:About \"locked\": We only support the token lock addresses or black hole addresses that we have included. )  # noqa: E501

        :param is_locked: The is_locked of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :type: int
        """

        self._is_locked = is_locked

    @property
    def is_contract(self):
        """Gets the is_contract of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501

        It describes whether the holder is a contract \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The is_contract of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :rtype: int
        """
        return self._is_contract

    @is_contract.setter
    def is_contract(self, is_contract):
        """Sets the is_contract of this ResponseWrapperTokenSecurityLpHolders.

        It describes whether the holder is a contract \"1\" means true; \"0\" means false.  # noqa: E501

        :param is_contract: The is_contract of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :type: int
        """

        self._is_contract = is_contract

    @property
    def address(self):
        """Gets the address of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501

        It describes the holder address;   # noqa: E501

        :return: The address of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this ResponseWrapperTokenSecurityLpHolders.

        It describes the holder address;   # noqa: E501

        :param address: The address of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def balance(self):
        """Gets the balance of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501

        It describes the balance of the holder.   # noqa: E501

        :return: The balance of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :rtype: str
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this ResponseWrapperTokenSecurityLpHolders.

        It describes the balance of the holder.   # noqa: E501

        :param balance: The balance of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :type: str
        """

        self._balance = balance

    @property
    def locked_detail(self):
        """Gets the locked_detail of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501

        It is an array, decribes lock position info of this holder, only shows when \"locked\": 1. This Array may contain multiple objects for multiple locking info. (Notice:When \"locked\":0, or lock address is a black hole address,  \"locked_detail\" will be no return.)  # noqa: E501

        :return: The locked_detail of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :rtype: list[ResponseWrapperTokenSecurityLockedDetail]
        """
        return self._locked_detail

    @locked_detail.setter
    def locked_detail(self, locked_detail):
        """Sets the locked_detail of this ResponseWrapperTokenSecurityLpHolders.

        It is an array, decribes lock position info of this holder, only shows when \"locked\": 1. This Array may contain multiple objects for multiple locking info. (Notice:When \"locked\":0, or lock address is a black hole address,  \"locked_detail\" will be no return.)  # noqa: E501

        :param locked_detail: The locked_detail of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :type: list[ResponseWrapperTokenSecurityLockedDetail]
        """

        self._locked_detail = locked_detail

    @property
    def tag(self):
        """Gets the tag of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501

        It describes the address's public tag. Example:Burn Address/Deployer;   # noqa: E501

        :return: The tag of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this ResponseWrapperTokenSecurityLpHolders.

        It describes the address's public tag. Example:Burn Address/Deployer;   # noqa: E501

        :param tag: The tag of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def percent(self):
        """Gets the percent of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501

        It  describes the percentage of tokens held by this holder (Notice:About \"percent\": 1 means 100% here.)  # noqa: E501

        :return: The percent of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :rtype: str
        """
        return self._percent

    @percent.setter
    def percent(self, percent):
        """Sets the percent of this ResponseWrapperTokenSecurityLpHolders.

        It  describes the percentage of tokens held by this holder (Notice:About \"percent\": 1 means 100% here.)  # noqa: E501

        :param percent: The percent of this ResponseWrapperTokenSecurityLpHolders.  # noqa: E501
        :type: str
        """

        self._percent = percent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperTokenSecurityLpHolders, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperTokenSecurityLpHolders):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperGetNftInfoResultSelfDestruct(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'owner_address': 'str',
        'value': 'int',
        'owner_type': 'str'
    }

    attribute_map = {
        'owner_address': 'owner_address',
        'value': 'value',
        'owner_type': 'owner_type'
    }

    def __init__(self, owner_address=None, value=None, owner_type=None):  # noqa: E501
        """ResponseWrapperGetNftInfoResultSelfDestruct - a model defined in Swagger"""  # noqa: E501
        self._owner_address = None
        self._value = None
        self._owner_type = None
        self.discriminator = None
        if owner_address is not None:
            self.owner_address = owner_address
        if value is not None:
            self.value = value
        if owner_type is not None:
            self.owner_type = owner_type

    @property
    def owner_address(self):
        """Gets the owner_address of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501

        Owner_address describes the owner address.  null: the owner address cannot be fetched.  # noqa: E501

        :return: The owner_address of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501
        :rtype: str
        """
        return self._owner_address

    @owner_address.setter
    def owner_address(self, owner_address):
        """Sets the owner_address of this ResponseWrapperGetNftInfoResultSelfDestruct.

        Owner_address describes the owner address.  null: the owner address cannot be fetched.  # noqa: E501

        :param owner_address: The owner_address of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501
        :type: str
        """

        self._owner_address = owner_address

    @property
    def value(self):
        """Gets the value of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501

        The \"value\" describes the status of the risk. null: the contract is not open source or there is a proxy, it is not possible to detect whether the risk exists. -1: the risk is detected but the ownership give up. If the detection of a code vulnerability, it can also be considered risk-free.  0: the risk is not detected.  1: the risk is detected, and the owner address is a common address (EOA), then it can be said that there is a clear risk.  2: The risk is detected, but the owner address is a contract address, the risk is not significant.  3: The risk is detected, but the owner address is not detectable / or an array.   # noqa: E501

        :return: The value of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ResponseWrapperGetNftInfoResultSelfDestruct.

        The \"value\" describes the status of the risk. null: the contract is not open source or there is a proxy, it is not possible to detect whether the risk exists. -1: the risk is detected but the ownership give up. If the detection of a code vulnerability, it can also be considered risk-free.  0: the risk is not detected.  1: the risk is detected, and the owner address is a common address (EOA), then it can be said that there is a clear risk.  2: The risk is detected, but the owner address is a contract address, the risk is not significant.  3: The risk is detected, but the owner address is not detectable / or an array.   # noqa: E501

        :param value: The value of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501
        :type: int
        """

        self._value = value

    @property
    def owner_type(self):
        """Gets the owner_type of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501

        \"blackhole\" : the owner is a blackhole address. \"contract\" : the owner is a contract. \"eoa\" : the owner is a common address (eoa). \"multi-address\": the owner is an array/list. null: the address is not detected.  # noqa: E501

        :return: The owner_type of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """Sets the owner_type of this ResponseWrapperGetNftInfoResultSelfDestruct.

        \"blackhole\" : the owner is a blackhole address. \"contract\" : the owner is a contract. \"eoa\" : the owner is a common address (eoa). \"multi-address\": the owner is an array/list. null: the address is not detected.  # noqa: E501

        :param owner_type: The owner_type of this ResponseWrapperGetNftInfoResultSelfDestruct.  # noqa: E501
        :type: str
        """

        self._owner_type = owner_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperGetNftInfoResultSelfDestruct, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperGetNftInfoResultSelfDestruct):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ApproveControllerV2Api(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def address_nft1155_approve_list_using_get1(self, addresses, chain_id, **kwargs):  # noqa: E501
        """Returns the ERC-1155 approvals of an EOA address and associated risk items.  # noqa: E501

        Reports the outstanding token approvals issued to ERC-1155 contracts by the given EOA address and associated risk items, including the date that the approval was issued, the allowance of the approval, and the transaction ID issuing the allowance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_nft1155_approve_list_using_get1(addresses, chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str addresses: contract address (required)
        :param str chain_id: chain id (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperListApproveNFT1155ListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_nft1155_approve_list_using_get1_with_http_info(addresses, chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.address_nft1155_approve_list_using_get1_with_http_info(addresses, chain_id, **kwargs)  # noqa: E501
            return data

    def address_nft1155_approve_list_using_get1_with_http_info(self, addresses, chain_id, **kwargs):  # noqa: E501
        """Returns the ERC-1155 approvals of an EOA address and associated risk items.  # noqa: E501

        Reports the outstanding token approvals issued to ERC-1155 contracts by the given EOA address and associated risk items, including the date that the approval was issued, the allowance of the approval, and the transaction ID issuing the allowance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_nft1155_approve_list_using_get1_with_http_info(addresses, chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str addresses: contract address (required)
        :param str chain_id: chain id (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperListApproveNFT1155ListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['addresses', 'chain_id', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_nft1155_approve_list_using_get1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'addresses' is set
        if ('addresses' not in params or
                params['addresses'] is None):
            raise ValueError("Missing the required parameter `addresses` when calling `address_nft1155_approve_list_using_get1`")  # noqa: E501
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in params or
                params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `address_nft1155_approve_list_using_get1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in params:
            path_params['chainId'] = params['chain_id']  # noqa: E501

        query_params = []
        if 'addresses' in params:
            query_params.append(('addresses', params['addresses']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/nft1155_approval_security/{chainId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseWrapperListApproveNFT1155ListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_nft721_approve_list_using_get1(self, addresses, chain_id, **kwargs):  # noqa: E501
        """Returns the ERC-721 approvals of an EOA address and associated risk items.  # noqa: E501

        Reports the outstanding token approvals issued to ERC-721 contracts by the given EOA address and associated risk items, including the date that the approval was issued, the allowance of the approval, and the transaction ID issuing the allowance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_nft721_approve_list_using_get1(addresses, chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str addresses: contract address (required)
        :param str chain_id: chain id (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperListApproveNFTListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_nft721_approve_list_using_get1_with_http_info(addresses, chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.address_nft721_approve_list_using_get1_with_http_info(addresses, chain_id, **kwargs)  # noqa: E501
            return data

    def address_nft721_approve_list_using_get1_with_http_info(self, addresses, chain_id, **kwargs):  # noqa: E501
        """Returns the ERC-721 approvals of an EOA address and associated risk items.  # noqa: E501

        Reports the outstanding token approvals issued to ERC-721 contracts by the given EOA address and associated risk items, including the date that the approval was issued, the allowance of the approval, and the transaction ID issuing the allowance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_nft721_approve_list_using_get1_with_http_info(addresses, chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str addresses: contract address (required)
        :param str chain_id: chain id (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperListApproveNFTListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['addresses', 'chain_id', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_nft721_approve_list_using_get1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'addresses' is set
        if ('addresses' not in params or
                params['addresses'] is None):
            raise ValueError("Missing the required parameter `addresses` when calling `address_nft721_approve_list_using_get1`")  # noqa: E501
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in params or
                params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `address_nft721_approve_list_using_get1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in params:
            path_params['chainId'] = params['chain_id']  # noqa: E501

        query_params = []
        if 'addresses' in params:
            query_params.append(('addresses', params['addresses']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/nft721_approval_security/{chainId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseWrapperListApproveNFTListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_token_approve_list_using_get1(self, addresses, chain_id, **kwargs):  # noqa: E501
        """Returns the ERC-20 approvals of an EOA address and associated risk items.  # noqa: E501

        Reports the outstanding token approvals issued to ERC-20 contracts by the given EOA address and associated risk items, including the date that the approval was issued, the allowance of the approval, and the transaction ID issuing the allowance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_token_approve_list_using_get1(addresses, chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str addresses: contract address (required)
        :param str chain_id: chain id (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperListApproveTokenOutListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_token_approve_list_using_get1_with_http_info(addresses, chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.address_token_approve_list_using_get1_with_http_info(addresses, chain_id, **kwargs)  # noqa: E501
            return data

    def address_token_approve_list_using_get1_with_http_info(self, addresses, chain_id, **kwargs):  # noqa: E501
        """Returns the ERC-20 approvals of an EOA address and associated risk items.  # noqa: E501

        Reports the outstanding token approvals issued to ERC-20 contracts by the given EOA address and associated risk items, including the date that the approval was issued, the allowance of the approval, and the transaction ID issuing the allowance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_token_approve_list_using_get1_with_http_info(addresses, chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str addresses: contract address (required)
        :param str chain_id: chain id (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperListApproveTokenOutListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['addresses', 'chain_id', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_token_approve_list_using_get1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'addresses' is set
        if ('addresses' not in params or
                params['addresses'] is None):
            raise ValueError("Missing the required parameter `addresses` when calling `address_token_approve_list_using_get1`")  # noqa: E501
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in params or
                params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `address_token_approve_list_using_get1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in params:
            path_params['chainId'] = params['chain_id']  # noqa: E501

        query_params = []
        if 'addresses' in params:
            query_params.append(('addresses', params['addresses']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/token_approval_security/{chainId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseWrapperListApproveTokenOutListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApproveTokenResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_info': 'ApproveAddressInfo',
        'approved_amount': 'str',
        'approved_contract': 'str',
        'approved_time': 'int',
        'hash': 'str',
        'initial_approval_hash': 'str',
        'initial_approval_time': 'int'
    }

    attribute_map = {
        'address_info': 'address_info',
        'approved_amount': 'approved_amount',
        'approved_contract': 'approved_contract',
        'approved_time': 'approved_time',
        'hash': 'hash',
        'initial_approval_hash': 'initial_approval_hash',
        'initial_approval_time': 'initial_approval_time'
    }

    def __init__(self, address_info=None, approved_amount=None, approved_contract=None, approved_time=None, hash=None, initial_approval_hash=None, initial_approval_time=None):  # noqa: E501
        """ApproveTokenResult - a model defined in Swagger"""  # noqa: E501
        self._address_info = None
        self._approved_amount = None
        self._approved_contract = None
        self._approved_time = None
        self._hash = None
        self._initial_approval_hash = None
        self._initial_approval_time = None
        self.discriminator = None
        if address_info is not None:
            self.address_info = address_info
        if approved_amount is not None:
            self.approved_amount = approved_amount
        if approved_contract is not None:
            self.approved_contract = approved_contract
        if approved_time is not None:
            self.approved_time = approved_time
        if hash is not None:
            self.hash = hash
        if initial_approval_hash is not None:
            self.initial_approval_hash = initial_approval_hash
        if initial_approval_time is not None:
            self.initial_approval_time = initial_approval_time

    @property
    def address_info(self):
        """Gets the address_info of this ApproveTokenResult.  # noqa: E501


        :return: The address_info of this ApproveTokenResult.  # noqa: E501
        :rtype: ApproveAddressInfo
        """
        return self._address_info

    @address_info.setter
    def address_info(self, address_info):
        """Sets the address_info of this ApproveTokenResult.


        :param address_info: The address_info of this ApproveTokenResult.  # noqa: E501
        :type: ApproveAddressInfo
        """

        self._address_info = address_info

    @property
    def approved_amount(self):
        """Gets the approved_amount of this ApproveTokenResult.  # noqa: E501

        Allowance of the spender  # noqa: E501

        :return: The approved_amount of this ApproveTokenResult.  # noqa: E501
        :rtype: str
        """
        return self._approved_amount

    @approved_amount.setter
    def approved_amount(self, approved_amount):
        """Sets the approved_amount of this ApproveTokenResult.

        Allowance of the spender  # noqa: E501

        :param approved_amount: The approved_amount of this ApproveTokenResult.  # noqa: E501
        :type: str
        """

        self._approved_amount = approved_amount

    @property
    def approved_contract(self):
        """Gets the approved_contract of this ApproveTokenResult.  # noqa: E501

        Spender Address  # noqa: E501

        :return: The approved_contract of this ApproveTokenResult.  # noqa: E501
        :rtype: str
        """
        return self._approved_contract

    @approved_contract.setter
    def approved_contract(self, approved_contract):
        """Sets the approved_contract of this ApproveTokenResult.

        Spender Address  # noqa: E501

        :param approved_contract: The approved_contract of this ApproveTokenResult.  # noqa: E501
        :type: str
        """

        self._approved_contract = approved_contract

    @property
    def approved_time(self):
        """Gets the approved_time of this ApproveTokenResult.  # noqa: E501

        Latest approval time  # noqa: E501

        :return: The approved_time of this ApproveTokenResult.  # noqa: E501
        :rtype: int
        """
        return self._approved_time

    @approved_time.setter
    def approved_time(self, approved_time):
        """Sets the approved_time of this ApproveTokenResult.

        Latest approval time  # noqa: E501

        :param approved_time: The approved_time of this ApproveTokenResult.  # noqa: E501
        :type: int
        """

        self._approved_time = approved_time

    @property
    def hash(self):
        """Gets the hash of this ApproveTokenResult.  # noqa: E501

        Latest approval hash  # noqa: E501

        :return: The hash of this ApproveTokenResult.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this ApproveTokenResult.

        Latest approval hash  # noqa: E501

        :param hash: The hash of this ApproveTokenResult.  # noqa: E501
        :type: str
        """

        self._hash = hash

    @property
    def initial_approval_hash(self):
        """Gets the initial_approval_hash of this ApproveTokenResult.  # noqa: E501

        Initial approval hash  # noqa: E501

        :return: The initial_approval_hash of this ApproveTokenResult.  # noqa: E501
        :rtype: str
        """
        return self._initial_approval_hash

    @initial_approval_hash.setter
    def initial_approval_hash(self, initial_approval_hash):
        """Sets the initial_approval_hash of this ApproveTokenResult.

        Initial approval hash  # noqa: E501

        :param initial_approval_hash: The initial_approval_hash of this ApproveTokenResult.  # noqa: E501
        :type: str
        """

        self._initial_approval_hash = initial_approval_hash

    @property
    def initial_approval_time(self):
        """Gets the initial_approval_time of this ApproveTokenResult.  # noqa: E501

        Initial approval time  # noqa: E501

        :return: The initial_approval_time of this ApproveTokenResult.  # noqa: E501
        :rtype: int
        """
        return self._initial_approval_time

    @initial_approval_time.setter
    def initial_approval_time(self, initial_approval_time):
        """Sets the initial_approval_time of this ApproveTokenResult.

        Initial approval time  # noqa: E501

        :param initial_approval_time: The initial_approval_time of this ApproveTokenResult.  # noqa: E501
        :type: int
        """

        self._initial_approval_time = initial_approval_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApproveTokenResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApproveTokenResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from swagger_client.api.token_controller_v_1_api import TokenControllerV1Api


class Chain(object):
    """
    Supported Blockchains
    """

    @classmethod
    def get_chain_list(cls, **kwargs):
        return TokenControllerV1Api().get_chains_list_using_get(**kwargs)



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DappContractSecurityResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'audit_info': 'list[AuditInfo]',
        'contracts_security': 'list[ContractsSecurity]',
        'is_audit': 'int',
        'project_name': 'str',
        'trust_list': 'int',
        'url': 'str'
    }

    attribute_map = {
        'audit_info': 'audit_info',
        'contracts_security': 'contracts_security',
        'is_audit': 'is_audit',
        'project_name': 'project_name',
        'trust_list': 'trust_list',
        'url': 'url'
    }

    def __init__(self, audit_info=None, contracts_security=None, is_audit=None, project_name=None, trust_list=None, url=None):  # noqa: E501
        """DappContractSecurityResponse - a model defined in Swagger"""  # noqa: E501
        self._audit_info = None
        self._contracts_security = None
        self._is_audit = None
        self._project_name = None
        self._trust_list = None
        self._url = None
        self.discriminator = None
        if audit_info is not None:
            self.audit_info = audit_info
        if contracts_security is not None:
            self.contracts_security = contracts_security
        if is_audit is not None:
            self.is_audit = is_audit
        if project_name is not None:
            self.project_name = project_name
        if trust_list is not None:
            self.trust_list = trust_list
        if url is not None:
            self.url = url

    @property
    def audit_info(self):
        """Gets the audit_info of this DappContractSecurityResponse.  # noqa: E501

        audit info(Notice:When the dApp was not audited, (\"is_audit\"=0), it will return \"null\".If there are multiple audit reports, the information of the latest audit report is displayed.)  # noqa: E501

        :return: The audit_info of this DappContractSecurityResponse.  # noqa: E501
        :rtype: list[AuditInfo]
        """
        return self._audit_info

    @audit_info.setter
    def audit_info(self, audit_info):
        """Sets the audit_info of this DappContractSecurityResponse.

        audit info(Notice:When the dApp was not audited, (\"is_audit\"=0), it will return \"null\".If there are multiple audit reports, the information of the latest audit report is displayed.)  # noqa: E501

        :param audit_info: The audit_info of this DappContractSecurityResponse.  # noqa: E501
        :type: list[AuditInfo]
        """

        self._audit_info = audit_info

    @property
    def contracts_security(self):
        """Gets the contracts_security of this DappContractSecurityResponse.  # noqa: E501


        :return: The contracts_security of this DappContractSecurityResponse.  # noqa: E501
        :rtype: list[ContractsSecurity]
        """
        return self._contracts_security

    @contracts_security.setter
    def contracts_security(self, contracts_security):
        """Sets the contracts_security of this DappContractSecurityResponse.


        :param contracts_security: The contracts_security of this DappContractSecurityResponse.  # noqa: E501
        :type: list[ContractsSecurity]
        """

        self._contracts_security = contracts_security

    @property
    def is_audit(self):
        """Gets the is_audit of this DappContractSecurityResponse.  # noqa: E501

        It describes whether the dApp was audited by a reputable audit firm. \"1\" means true; \"0\" means that we have not found audit information for this dApp .(Notice:Return \"0\" does not mean the dApp was not audited. Maybe we just haven't found audit information for this dApp yet.)  # noqa: E501

        :return: The is_audit of this DappContractSecurityResponse.  # noqa: E501
        :rtype: int
        """
        return self._is_audit

    @is_audit.setter
    def is_audit(self, is_audit):
        """Sets the is_audit of this DappContractSecurityResponse.

        It describes whether the dApp was audited by a reputable audit firm. \"1\" means true; \"0\" means that we have not found audit information for this dApp .(Notice:Return \"0\" does not mean the dApp was not audited. Maybe we just haven't found audit information for this dApp yet.)  # noqa: E501

        :param is_audit: The is_audit of this DappContractSecurityResponse.  # noqa: E501
        :type: int
        """

        self._is_audit = is_audit

    @property
    def project_name(self):
        """Gets the project_name of this DappContractSecurityResponse.  # noqa: E501

        It describes the dApp project name.  # noqa: E501

        :return: The project_name of this DappContractSecurityResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DappContractSecurityResponse.

        It describes the dApp project name.  # noqa: E501

        :param project_name: The project_name of this DappContractSecurityResponse.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def trust_list(self):
        """Gets the trust_list of this DappContractSecurityResponse.  # noqa: E501

        It describes whether the dapp is a famous and trustworthy one. \"1\" means true;  \"0\" means that this dapp is not yet in our trusted list.(Notice:(1) Only \"trust_list\": \"1\" means it is a famous and trustworthy dapp.  (2) \"0\" return doesn't mean it is risky.)  # noqa: E501

        :return: The trust_list of this DappContractSecurityResponse.  # noqa: E501
        :rtype: int
        """
        return self._trust_list

    @trust_list.setter
    def trust_list(self, trust_list):
        """Sets the trust_list of this DappContractSecurityResponse.

        It describes whether the dapp is a famous and trustworthy one. \"1\" means true;  \"0\" means that this dapp is not yet in our trusted list.(Notice:(1) Only \"trust_list\": \"1\" means it is a famous and trustworthy dapp.  (2) \"0\" return doesn't mean it is risky.)  # noqa: E501

        :param trust_list: The trust_list of this DappContractSecurityResponse.  # noqa: E501
        :type: int
        """

        self._trust_list = trust_list

    @property
    def url(self):
        """Gets the url of this DappContractSecurityResponse.  # noqa: E501

        It describes the dApp's website link.  # noqa: E501

        :return: The url of this DappContractSecurityResponse.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this DappContractSecurityResponse.

        It describes the dApp's website link.  # noqa: E501

        :param url: The url of this DappContractSecurityResponse.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DappContractSecurityResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DappContractSecurityResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import hashlib
import time

from swagger_client.api.token_controller_api import TokenControllerApi


class Auth(object):
    def __init__(self, key, secret):
        self.__check(key, secret)
        self.key = key
        self.secret = secret
        self.api = TokenControllerApi()

    @staticmethod
    def __check(key, secret):
        if not (key and secret):
            raise ValueError("invalid key")

    @staticmethod
    def __sign(key, secret, t):
        s = key + str(t) + secret
        sha1 = hashlib.sha1()
        sha1.update(s.encode("utf-8"))
        return sha1.hexdigest()

    def get_access_token(self, **kwargs):
        t = int(time.time())
        body = {
            "app_key": self.key,
            "sign": self.__sign(self.key, self.secret, t),
            "time": t,
        }
        return self.api.get_access_token_using_post(**{"body": body}, **kwargs)
